==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/FirmwareConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FirmwareConfigFluentImpl<A extends FirmwareConfigFluent<A>> extends BaseFluent<A> implements FirmwareConfigFluent<A>{
  public FirmwareConfigFluentImpl() {
  }
  public FirmwareConfigFluentImpl(FirmwareConfig instance) {
    this.withSimultaneousMultithreadingEnabled(instance.getSimultaneousMultithreadingEnabled()); 
    this.withSriovEnabled(instance.getSriovEnabled()); 
    this.withVirtualizationEnabled(instance.getVirtualizationEnabled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Boolean simultaneousMultithreadingEnabled;
  private Boolean sriovEnabled;
  private Boolean virtualizationEnabled;
  private Map<String,Object> additionalProperties;
  public Boolean getSimultaneousMultithreadingEnabled() {
    return this.simultaneousMultithreadingEnabled;
  }
  public A withSimultaneousMultithreadingEnabled(Boolean simultaneousMultithreadingEnabled) {
    this.simultaneousMultithreadingEnabled=simultaneousMultithreadingEnabled; return (A) this;
  }
  public Boolean hasSimultaneousMultithreadingEnabled() {
    return this.simultaneousMultithreadingEnabled != null;
  }
  public Boolean getSriovEnabled() {
    return this.sriovEnabled;
  }
  public A withSriovEnabled(Boolean sriovEnabled) {
    this.sriovEnabled=sriovEnabled; return (A) this;
  }
  public Boolean hasSriovEnabled() {
    return this.sriovEnabled != null;
  }
  public Boolean getVirtualizationEnabled() {
    return this.virtualizationEnabled;
  }
  public A withVirtualizationEnabled(Boolean virtualizationEnabled) {
    this.virtualizationEnabled=virtualizationEnabled; return (A) this;
  }
  public Boolean hasVirtualizationEnabled() {
    return this.virtualizationEnabled != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    FirmwareConfigFluentImpl that = (FirmwareConfigFluentImpl) o;
    if (simultaneousMultithreadingEnabled != null ? !simultaneousMultithreadingEnabled.equals(that.simultaneousMultithreadingEnabled) :that.simultaneousMultithreadingEnabled != null) return false;
    if (sriovEnabled != null ? !sriovEnabled.equals(that.sriovEnabled) :that.sriovEnabled != null) return false;
    if (virtualizationEnabled != null ? !virtualizationEnabled.equals(that.virtualizationEnabled) :that.virtualizationEnabled != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(simultaneousMultithreadingEnabled,  sriovEnabled,  virtualizationEnabled,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (simultaneousMultithreadingEnabled != null) { sb.append("simultaneousMultithreadingEnabled:"); sb.append(simultaneousMultithreadingEnabled + ","); }
    if (sriovEnabled != null) { sb.append("sriovEnabled:"); sb.append(sriovEnabled + ","); }
    if (virtualizationEnabled != null) { sb.append("virtualizationEnabled:"); sb.append(virtualizationEnabled + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withSimultaneousMultithreadingEnabled() {
    return withSimultaneousMultithreadingEnabled(true);
  }
  public A withSriovEnabled() {
    return withSriovEnabled(true);
  }
  public A withVirtualizationEnabled() {
    return withVirtualizationEnabled(true);
  }
  
}

==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/FirmwareConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FirmwareConfigFluentImpl<A extends FirmwareConfigFluent<A>> extends BaseFluent<A> implements FirmwareConfigFluent<A>{
  public FirmwareConfigFluentImpl() {
  }
  public FirmwareConfigFluentImpl(FirmwareConfig instance) {
    if (instance != null) {
      this.withSimultaneousMultithreadingEnabled(instance.getSimultaneousMultithreadingEnabled());
      this.withSriovEnabled(instance.getSriovEnabled());
      this.withVirtualizationEnabled(instance.getVirtualizationEnabled());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Boolean simultaneousMultithreadingEnabled;
  private Boolean sriovEnabled;
  private Boolean virtualizationEnabled;
  private Map<String,Object> additionalProperties;
  public Boolean getSimultaneousMultithreadingEnabled() {
    return this.simultaneousMultithreadingEnabled;
  }
  public A withSimultaneousMultithreadingEnabled(Boolean simultaneousMultithreadingEnabled) {
    this.simultaneousMultithreadingEnabled=simultaneousMultithreadingEnabled; return (A) this;
  }
  public Boolean hasSimultaneousMultithreadingEnabled() {
    return this.simultaneousMultithreadingEnabled != null;
  }
  public Boolean getSriovEnabled() {
    return this.sriovEnabled;
  }
  public A withSriovEnabled(Boolean sriovEnabled) {
    this.sriovEnabled=sriovEnabled; return (A) this;
  }
  public Boolean hasSriovEnabled() {
    return this.sriovEnabled != null;
  }
  public Boolean getVirtualizationEnabled() {
    return this.virtualizationEnabled;
  }
  public A withVirtualizationEnabled(Boolean virtualizationEnabled) {
    this.virtualizationEnabled=virtualizationEnabled; return (A) this;
  }
  public Boolean hasVirtualizationEnabled() {
    return this.virtualizationEnabled != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FirmwareConfigFluentImpl that = (FirmwareConfigFluentImpl) o;
    if (!java.util.Objects.equals(simultaneousMultithreadingEnabled, that.simultaneousMultithreadingEnabled)) return false;

    if (!java.util.Objects.equals(sriovEnabled, that.sriovEnabled)) return false;

    if (!java.util.Objects.equals(virtualizationEnabled, that.virtualizationEnabled)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(simultaneousMultithreadingEnabled,  sriovEnabled,  virtualizationEnabled,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (simultaneousMultithreadingEnabled != null) { sb.append("simultaneousMultithreadingEnabled:"); sb.append(simultaneousMultithreadingEnabled + ","); }
    if (sriovEnabled != null) { sb.append("sriovEnabled:"); sb.append(sriovEnabled + ","); }
    if (virtualizationEnabled != null) { sb.append("virtualizationEnabled:"); sb.append(virtualizationEnabled + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withSimultaneousMultithreadingEnabled() {
    return withSimultaneousMultithreadingEnabled(true);
  }
  public A withSriovEnabled() {
    return withSriovEnabled(true);
  }
  public A withVirtualizationEnabled() {
    return withVirtualizationEnabled(true);
  }
  
}
